// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) space 
// Source File Name:   ResultRepository.java

package lt.ktu.gmj;


// Referenced classes of package lt.ktu.gmj:
//            ResultObserver, Result, Task, Method

public interface ResultRepository
{

    public abstract void addObserver(ResultObserver resultobserver);

    public abstract void removeObserver(ResultObserver resultobserver);

    public abstract int resultCount();

    public abstract Result resultAt(int i);

    public abstract int progressResultCount();

    public abstract Result progressResultAt(int i);

    public abstract Result lastResult();

    public abstract Task task();

    public abstract Method method();

    public abstract double minValue();

    public abstract double maxValue();
}
